Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2917)

Unified Diff: bench/BenchLogger.h

Issue 347823004: Remove Sk prefix from some bench classes. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: SkGMBench -> GMBench Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « bench/AAClipBench.cpp ('k') | bench/BenchLogger.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: bench/BenchLogger.h
diff --git a/bench/SkBenchLogger.h b/bench/BenchLogger.h
similarity index 89%
rename from bench/SkBenchLogger.h
rename to bench/BenchLogger.h
index 77a08373bf686e327e2f7c561110c17fdadf79a1..a7c283ad50516a585f0772eb73c2bcd61e1853c1 100644
--- a/bench/SkBenchLogger.h
+++ b/bench/BenchLogger.h
@@ -1,4 +1,3 @@
-
/*
* Copyright 2012 Google Inc.
*
@@ -6,30 +5,30 @@
* found in the LICENSE file.
*/
-#ifndef SkBenchLogger_DEFINED
-#define SkBenchLogger_DEFINED
+#ifndef BenchLogger_DEFINED
+#define BenchLogger_DEFINED
-#include "SkTypes.h"
-#include "SkString.h"
#include <stdio.h>
+#include "SkString.h"
+#include "SkTypes.h"
class SkFILEWStream;
/**
* Class that allows logging to a file while simultaneously logging to stdout/stderr.
*/
-class SkBenchLogger {
+class BenchLogger {
public:
- SkBenchLogger();
+ BenchLogger();
/**
* Not virtual, since this class is not intended to be subclassed.
*/
- ~SkBenchLogger();
+ ~BenchLogger();
/**
* Specify a file to write progress logs to. Unless this is called with a valid file path,
* SkBenchLogger will only write to stdout/stderr.
*/
bool SetLogFile(const char file[]);
@@ -74,4 +73,4 @@ private:
SkFILEWStream* fFileStream;
};
-#endif // SkBenchLogger_DEFINED
+#endif // BenchLogger_DEFINED
« no previous file with comments | « bench/AAClipBench.cpp ('k') | bench/BenchLogger.cpp » ('j') | no next file with comments »

Powered by Google App Engine
@@ -6,30 +5,30 @@
/**
* Specify a file to write progress logs to. Unless this is called with a valid file path,
- * SkBenchLogger will only write to stdout/stderr.
+ * BenchLogger will only write to stdout/stderr.
*/
bool SetLogFile(const char file[]);
This is Rietveld 408576698